@@ -1,7 +1,7 @@
 import select
 import sys
 from functools import wraps
-from typing import Any, Callable, Dict, List, Optional, Type, TypeVar, Union, cast
+from typing import Any, Callable, Dict, List, Optional, Tuple, Type, TypeVar, Union, cast
 
 from arcor2.cached import CachedProject, CachedScene
 from arcor2.data.events import ActionStateAfter, ActionStateBefore, Event, PackageState
@@ -10,7 +10,7 @@ from arcor2.object_types.abstract import Generic
 from arcor2.object_types.utils import iterate_over_actions
 from arcor2.parameter_plugins.utils import plugin_from_instance
 
-HANDLE_ACTIONS = True
+HANDLE_ACTIONS = True  # setting this to False disables checking for commands and printing out events
 
 
 def get_action_name_to_id(scene: CachedScene, project: CachedProject, object_type: str) -> Dict[str, str]:
@@ -66,7 +66,15 @@ except ImportError:
         return None
 
 
-def handle_action() -> None:
+def handle_stdin_commands() -> None:
+    """Reads stdin and checks for commands from parent script (e.g. Execution
+    unit). Prints events to stdout.
+
+    p == pause script
+    r == resume script
+
+    :return:
+    """
 
     ctrl_cmd = read_stdin()
 
@@ -106,25 +114,47 @@ def results_to_json(res: Any) -> Optional[List[str]]:
         return [plugin_from_instance(res).value_to_json(res)]
 
 
+_executed_action: Optional[Tuple[str, Callable]] = None
+
+
 def action(f: F) -> F:
+    """Action decorator that prints events with action id and parameters or
+    results.
+
+    :param f: action method
+    :return:
+    """
+
     @wraps(f)
     def wrapper(*args: Union[Generic, Any], an: Optional[str] = None, **kwargs: Any) -> Any:
 
+        global _executed_action
+
         action_args = args[1:]
         action_id: Optional[str] = None
 
-        try:
-            action_id = args[0].action_name_to_id[an]  # type: ignore
-        except AttributeError:
-            # mapping from action name to id not provided, ActionState won't be sent
-            pass
-        except KeyError:
-            if an is None:
-                raise Arcor2Exception("Mapping from action name to id provided, but action name not set.")
-            raise Arcor2Exception(f"Mapping from action name to id is missing key {an}.")
+        if HANDLE_ACTIONS:  # if not set, ignore everything
 
-        if not action.inside_composite and HANDLE_ACTIONS:  # type: ignore
-            if action_id:
+            if _executed_action and an:
+                raise Arcor2Exception("Inner actions should not have name specified.")
+
+            if not _executed_action:  # do not attempt to get id for inner actions
+                try:
+                    action_id = args[0].action_name_to_id[an]  # type: ignore
+                except AttributeError:
+                    # mapping from action name to id not provided, ActionState won't be sent
+                    pass
+                except KeyError:
+                    if an is None:
+                        raise Arcor2Exception("Mapping from action name to id provided, but action name not set.")
+                    raise Arcor2Exception(f"Mapping from action name to id is missing key {an}.")
+
+            if _executed_action and not _executed_action[1].__action__.composite:  # type: ignore
+                msg = f"Outer action {_executed_action[1].__name__}/{_executed_action[0]} not flagged as composite."
+                _executed_action = None
+                raise Arcor2Exception(msg)
+
+            if action_id:  # can't do much without action_id
                 print_event(
                     ActionStateBefore(
                         ActionStateBefore.Data(
@@ -134,24 +164,30 @@ def action(f: F) -> F:
                         )
                     )
                 )
-            handle_action()
 
-        if wrapper.__action__.composite:  # type: ignore # TODO and not step_into
-            action.inside_composite = f  # type: ignore
+                if _executed_action is None:
+                    _executed_action = action_id, f
 
-        res = f(*args, an=an, **kwargs)
+        handle_stdin_commands()
 
-        if action.inside_composite == f:  # type: ignore
-            action.inside_composite = None  # type: ignore
+        try:
+            res = f(*args, an=an, **kwargs)
+        except Arcor2Exception:
+            # this is actually not necessary at the moment as when exception is raised, the script ends anyway
+            _executed_action = None
+            # TODO maybe print ProjectException from here instead of from Resources' context manager?
+            # ...could provide action_id from here
+            raise
 
-        if not action.inside_composite and HANDLE_ACTIONS:  # type: ignore
+        if HANDLE_ACTIONS:
             if action_id:
-                print_event(ActionStateAfter(ActionStateAfter.Data(action_id, results_to_json(res))))
-            handle_action()
+                # we are getting out of (composite) action
+                if _executed_action and _executed_action[0] == action_id:
+                    _executed_action = None
+                    print_event(ActionStateAfter(ActionStateAfter.Data(action_id, results_to_json(res))))
+
+        handle_stdin_commands()
 
         return res
 
     return cast(F, wrapper)
-
-
-action.inside_composite = None  # type: ignore
