@@ -1,9 +1,8 @@
 import copy
 import json
+from ast import Attribute, Load, Name
 from typing import Any, List
 
-from typed_ast.ast3 import Attribute, Load, Name
-
 from arcor2 import transformations as tr
 from arcor2.cached import CachedProject as CProject
 from arcor2.cached import CachedScene as CScene
@@ -58,13 +57,12 @@ class PosePlugin(ParameterPlugin):
         cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str
     ) -> Attribute:
 
-        ap, _ = project.action_point_and_action(action_id)
-        ori = project.orientation(cls.orientation_id(project, action_id, parameter_id))
+        ori_ap, ori = project.bare_ap_and_orientation(cls.orientation_id(project, action_id, parameter_id))
 
         return Attribute(
             value=Attribute(
                 value=Attribute(
-                    value=Name(id="aps", ctx=Load()), attr=ap.name, ctx=Load()  # TODO this should not be hardcoded
+                    value=Name(id="aps", ctx=Load()), attr=ori_ap.name, ctx=Load()  # TODO this should not be hardcoded
                 ),
                 attr="poses",  # TODO this should not be hardcoded
                 ctx=Load(),
